Class: Aws::Synthetics::Types::AddReplicaLocationInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-synthetics/types.rb

Overview

A structure that specifies a replica location for a canary, including the Region and optional VPC configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#kms_key_arnString

The Amazon Resource Name (ARN) of the customer-managed AWS Key Management Service (AWS KMS) key used to encrypt the canary replica's AWS Lambda function environment variables at rest. If you don't specify a value, the service uses an AWS-managed key.

Returns:

  • (String)


49
50
51
52
53
54
55
# File 'lib/aws-sdk-synthetics/types.rb', line 49

class AddReplicaLocationInput < Struct.new(
  :location,
  :vpc_config,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

The Amazon Web Services Region where the canary replica should be created, for example us-east-1.

Returns:

  • (String)


49
50
51
52
53
54
55
# File 'lib/aws-sdk-synthetics/types.rb', line 49

class AddReplicaLocationInput < Struct.new(
  :location,
  :vpc_config,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::VpcConfigInput

The VPC configuration to use for the canary replica in this location. If not specified, the replica runs without VPC connectivity.



49
50
51
52
53
54
55
# File 'lib/aws-sdk-synthetics/types.rb', line 49

class AddReplicaLocationInput < Struct.new(
  :location,
  :vpc_config,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end