Class: Aws::Synthetics::Types::Canary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Synthetics::Types::Canary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-synthetics/types.rb
Overview
This structure contains all information about one canary in your account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#artifact_config ⇒ Types::ArtifactConfigOutput
A structure that contains the configuration for canary artifacts, including the encryption-at-rest settings for artifacts that the canary uploads to Amazon S3.
-
#artifact_s3_location ⇒ String
The location in Amazon S3 where Synthetics stores artifacts from the runs of this canary.
-
#browser_configs ⇒ Array<Types::BrowserConfig>
A structure that specifies the browser type to use for a canary run.
-
#code ⇒ Types::CanaryCodeOutput
This structure contains information about the canary’s Lambda handler and where its code is stored by CloudWatch Synthetics.
-
#dry_run_config ⇒ Types::DryRunConfigOutput
Returns the dry run configurations for a canary.
-
#engine_arn ⇒ String
The ARN of the Lambda function that is used as your canary’s engine.
-
#engine_configs ⇒ Array<Types::EngineConfig>
A list of engine configurations for the canary, one for each browser type that the canary is configured to run on.
-
#execution_role_arn ⇒ String
The ARN of the IAM role used to run the canary.
-
#failure_retention_period_in_days ⇒ Integer
The number of days to retain data about failed runs of this canary.
-
#id ⇒ String
The unique ID of this canary.
-
#name ⇒ String
The name of the canary.
-
#provisioned_resource_cleanup ⇒ String
Specifies whether to also delete the Lambda functions and layers used by this canary when the canary is deleted.
-
#run_config ⇒ Types::CanaryRunConfigOutput
A structure that contains information about a canary run.
-
#runtime_version ⇒ String
Specifies the runtime version to use for the canary.
-
#schedule ⇒ Types::CanaryScheduleOutput
A structure that contains information about how often the canary is to run, and when these runs are to stop.
-
#status ⇒ Types::CanaryStatus
A structure that contains information about the canary’s status.
-
#success_retention_period_in_days ⇒ Integer
The number of days to retain data about successful runs of this canary.
-
#tags ⇒ Hash<String,String>
The list of key-value pairs that are associated with the canary.
-
#timeline ⇒ Types::CanaryTimeline
A structure that contains information about when the canary was created, modified, and most recently run.
-
#visual_reference ⇒ Types::VisualReferenceOutput
If this canary performs visual monitoring by comparing screenshots, this structure contains the ID of the canary run to use as the baseline for screenshots, and the coordinates of any parts of the screen to ignore during the visual monitoring comparison.
-
#visual_references ⇒ Array<Types::VisualReferenceOutput>
A list of visual reference configurations for the canary, one for each browser type that the canary is configured to run on.
-
#vpc_config ⇒ Types::VpcConfigOutput
If this canary is to test an endpoint in a VPC, this structure contains information about the subnets and security groups of the VPC endpoint.
Instance Attribute Details
#artifact_config ⇒ Types::ArtifactConfigOutput
A structure that contains the configuration for canary artifacts, including the encryption-at-rest settings for artifacts that the canary uploads to Amazon S3.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-synthetics/types.rb', line 324 class Canary < Struct.new( :id, :name, :code, :execution_role_arn, :schedule, :run_config, :success_retention_period_in_days, :failure_retention_period_in_days, :status, :timeline, :artifact_s3_location, :engine_arn, :runtime_version, :vpc_config, :visual_reference, :provisioned_resource_cleanup, :browser_configs, :engine_configs, :visual_references, :tags, :artifact_config, :dry_run_config) SENSITIVE = [] include Aws::Structure end |
#artifact_s3_location ⇒ String
The location in Amazon S3 where Synthetics stores artifacts from the runs of this canary. Artifacts include the log file, screenshots, and HAR files.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-synthetics/types.rb', line 324 class Canary < Struct.new( :id, :name, :code, :execution_role_arn, :schedule, :run_config, :success_retention_period_in_days, :failure_retention_period_in_days, :status, :timeline, :artifact_s3_location, :engine_arn, :runtime_version, :vpc_config, :visual_reference, :provisioned_resource_cleanup, :browser_configs, :engine_configs, :visual_references, :tags, :artifact_config, :dry_run_config) SENSITIVE = [] include Aws::Structure end |
#browser_configs ⇒ Array<Types::BrowserConfig>
A structure that specifies the browser type to use for a canary run. CloudWatch Synthetics supports running canaries on both ‘CHROME` and `FIREFOX` browsers.
<note markdown=“1”> If not specified, ‘browserConfigs` defaults to Chrome.
</note>
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-synthetics/types.rb', line 324 class Canary < Struct.new( :id, :name, :code, :execution_role_arn, :schedule, :run_config, :success_retention_period_in_days, :failure_retention_period_in_days, :status, :timeline, :artifact_s3_location, :engine_arn, :runtime_version, :vpc_config, :visual_reference, :provisioned_resource_cleanup, :browser_configs, :engine_configs, :visual_references, :tags, :artifact_config, :dry_run_config) SENSITIVE = [] include Aws::Structure end |
#code ⇒ Types::CanaryCodeOutput
This structure contains information about the canary’s Lambda handler and where its code is stored by CloudWatch Synthetics.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-synthetics/types.rb', line 324 class Canary < Struct.new( :id, :name, :code, :execution_role_arn, :schedule, :run_config, :success_retention_period_in_days, :failure_retention_period_in_days, :status, :timeline, :artifact_s3_location, :engine_arn, :runtime_version, :vpc_config, :visual_reference, :provisioned_resource_cleanup, :browser_configs, :engine_configs, :visual_references, :tags, :artifact_config, :dry_run_config) SENSITIVE = [] include Aws::Structure end |
#dry_run_config ⇒ Types::DryRunConfigOutput
Returns the dry run configurations for a canary.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-synthetics/types.rb', line 324 class Canary < Struct.new( :id, :name, :code, :execution_role_arn, :schedule, :run_config, :success_retention_period_in_days, :failure_retention_period_in_days, :status, :timeline, :artifact_s3_location, :engine_arn, :runtime_version, :vpc_config, :visual_reference, :provisioned_resource_cleanup, :browser_configs, :engine_configs, :visual_references, :tags, :artifact_config, :dry_run_config) SENSITIVE = [] include Aws::Structure end |
#engine_arn ⇒ String
The ARN of the Lambda function that is used as your canary’s engine. For more information about Lambda ARN format, see [Resources and Conditions for Lambda Actions].
[1]: docs.aws.amazon.com/lambda/latest/dg/lambda-api-permissions-ref.html
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-synthetics/types.rb', line 324 class Canary < Struct.new( :id, :name, :code, :execution_role_arn, :schedule, :run_config, :success_retention_period_in_days, :failure_retention_period_in_days, :status, :timeline, :artifact_s3_location, :engine_arn, :runtime_version, :vpc_config, :visual_reference, :provisioned_resource_cleanup, :browser_configs, :engine_configs, :visual_references, :tags, :artifact_config, :dry_run_config) SENSITIVE = [] include Aws::Structure end |
#engine_configs ⇒ Array<Types::EngineConfig>
A list of engine configurations for the canary, one for each browser type that the canary is configured to run on.
All runtime versions ‘syn-nodejs-puppeteer-11.0` and above, and `syn-nodejs-playwright-3.0` and above, use `engineConfigs` only. You can no longer use `engineArn` in these versions.
Runtime versions older than ‘syn-nodejs-puppeteer-11.0` and `syn-nodejs-playwright-3.0` continue to support `engineArn` to ensure backward compatibility.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-synthetics/types.rb', line 324 class Canary < Struct.new( :id, :name, :code, :execution_role_arn, :schedule, :run_config, :success_retention_period_in_days, :failure_retention_period_in_days, :status, :timeline, :artifact_s3_location, :engine_arn, :runtime_version, :vpc_config, :visual_reference, :provisioned_resource_cleanup, :browser_configs, :engine_configs, :visual_references, :tags, :artifact_config, :dry_run_config) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The ARN of the IAM role used to run the canary. This role must include ‘lambda.amazonaws.com` as a principal in the trust policy.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-synthetics/types.rb', line 324 class Canary < Struct.new( :id, :name, :code, :execution_role_arn, :schedule, :run_config, :success_retention_period_in_days, :failure_retention_period_in_days, :status, :timeline, :artifact_s3_location, :engine_arn, :runtime_version, :vpc_config, :visual_reference, :provisioned_resource_cleanup, :browser_configs, :engine_configs, :visual_references, :tags, :artifact_config, :dry_run_config) SENSITIVE = [] include Aws::Structure end |
#failure_retention_period_in_days ⇒ Integer
The number of days to retain data about failed runs of this canary.
This setting affects the range of information returned by [GetCanaryRuns], as well as the range of information displayed in the Synthetics console.
[1]: docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_GetCanaryRuns.html
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-synthetics/types.rb', line 324 class Canary < Struct.new( :id, :name, :code, :execution_role_arn, :schedule, :run_config, :success_retention_period_in_days, :failure_retention_period_in_days, :status, :timeline, :artifact_s3_location, :engine_arn, :runtime_version, :vpc_config, :visual_reference, :provisioned_resource_cleanup, :browser_configs, :engine_configs, :visual_references, :tags, :artifact_config, :dry_run_config) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique ID of this canary.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-synthetics/types.rb', line 324 class Canary < Struct.new( :id, :name, :code, :execution_role_arn, :schedule, :run_config, :success_retention_period_in_days, :failure_retention_period_in_days, :status, :timeline, :artifact_s3_location, :engine_arn, :runtime_version, :vpc_config, :visual_reference, :provisioned_resource_cleanup, :browser_configs, :engine_configs, :visual_references, :tags, :artifact_config, :dry_run_config) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the canary.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-synthetics/types.rb', line 324 class Canary < Struct.new( :id, :name, :code, :execution_role_arn, :schedule, :run_config, :success_retention_period_in_days, :failure_retention_period_in_days, :status, :timeline, :artifact_s3_location, :engine_arn, :runtime_version, :vpc_config, :visual_reference, :provisioned_resource_cleanup, :browser_configs, :engine_configs, :visual_references, :tags, :artifact_config, :dry_run_config) SENSITIVE = [] include Aws::Structure end |
#provisioned_resource_cleanup ⇒ String
Specifies whether to also delete the Lambda functions and layers used by this canary when the canary is deleted. If it is ‘AUTOMATIC`, the Lambda functions and layers will be deleted when the canary is deleted.
If the value of this parameter is ‘OFF`, then the value of the `DeleteLambda` parameter of the [DeleteCanary] operation determines whether the Lambda functions and layers will be deleted.
[1]: docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_DeleteCanary.html
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-synthetics/types.rb', line 324 class Canary < Struct.new( :id, :name, :code, :execution_role_arn, :schedule, :run_config, :success_retention_period_in_days, :failure_retention_period_in_days, :status, :timeline, :artifact_s3_location, :engine_arn, :runtime_version, :vpc_config, :visual_reference, :provisioned_resource_cleanup, :browser_configs, :engine_configs, :visual_references, :tags, :artifact_config, :dry_run_config) SENSITIVE = [] include Aws::Structure end |
#run_config ⇒ Types::CanaryRunConfigOutput
A structure that contains information about a canary run.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-synthetics/types.rb', line 324 class Canary < Struct.new( :id, :name, :code, :execution_role_arn, :schedule, :run_config, :success_retention_period_in_days, :failure_retention_period_in_days, :status, :timeline, :artifact_s3_location, :engine_arn, :runtime_version, :vpc_config, :visual_reference, :provisioned_resource_cleanup, :browser_configs, :engine_configs, :visual_references, :tags, :artifact_config, :dry_run_config) SENSITIVE = [] include Aws::Structure end |
#runtime_version ⇒ String
Specifies the runtime version to use for the canary. For more information about runtime versions, see [ Canary Runtime Versions].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch_Synthetics_Canaries_Library.html
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-synthetics/types.rb', line 324 class Canary < Struct.new( :id, :name, :code, :execution_role_arn, :schedule, :run_config, :success_retention_period_in_days, :failure_retention_period_in_days, :status, :timeline, :artifact_s3_location, :engine_arn, :runtime_version, :vpc_config, :visual_reference, :provisioned_resource_cleanup, :browser_configs, :engine_configs, :visual_references, :tags, :artifact_config, :dry_run_config) SENSITIVE = [] include Aws::Structure end |
#schedule ⇒ Types::CanaryScheduleOutput
A structure that contains information about how often the canary is to run, and when these runs are to stop.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-synthetics/types.rb', line 324 class Canary < Struct.new( :id, :name, :code, :execution_role_arn, :schedule, :run_config, :success_retention_period_in_days, :failure_retention_period_in_days, :status, :timeline, :artifact_s3_location, :engine_arn, :runtime_version, :vpc_config, :visual_reference, :provisioned_resource_cleanup, :browser_configs, :engine_configs, :visual_references, :tags, :artifact_config, :dry_run_config) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::CanaryStatus
A structure that contains information about the canary’s status.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-synthetics/types.rb', line 324 class Canary < Struct.new( :id, :name, :code, :execution_role_arn, :schedule, :run_config, :success_retention_period_in_days, :failure_retention_period_in_days, :status, :timeline, :artifact_s3_location, :engine_arn, :runtime_version, :vpc_config, :visual_reference, :provisioned_resource_cleanup, :browser_configs, :engine_configs, :visual_references, :tags, :artifact_config, :dry_run_config) SENSITIVE = [] include Aws::Structure end |
#success_retention_period_in_days ⇒ Integer
The number of days to retain data about successful runs of this canary.
This setting affects the range of information returned by [GetCanaryRuns], as well as the range of information displayed in the Synthetics console.
[1]: docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_GetCanaryRuns.html
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-synthetics/types.rb', line 324 class Canary < Struct.new( :id, :name, :code, :execution_role_arn, :schedule, :run_config, :success_retention_period_in_days, :failure_retention_period_in_days, :status, :timeline, :artifact_s3_location, :engine_arn, :runtime_version, :vpc_config, :visual_reference, :provisioned_resource_cleanup, :browser_configs, :engine_configs, :visual_references, :tags, :artifact_config, :dry_run_config) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The list of key-value pairs that are associated with the canary.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-synthetics/types.rb', line 324 class Canary < Struct.new( :id, :name, :code, :execution_role_arn, :schedule, :run_config, :success_retention_period_in_days, :failure_retention_period_in_days, :status, :timeline, :artifact_s3_location, :engine_arn, :runtime_version, :vpc_config, :visual_reference, :provisioned_resource_cleanup, :browser_configs, :engine_configs, :visual_references, :tags, :artifact_config, :dry_run_config) SENSITIVE = [] include Aws::Structure end |
#timeline ⇒ Types::CanaryTimeline
A structure that contains information about when the canary was created, modified, and most recently run.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-synthetics/types.rb', line 324 class Canary < Struct.new( :id, :name, :code, :execution_role_arn, :schedule, :run_config, :success_retention_period_in_days, :failure_retention_period_in_days, :status, :timeline, :artifact_s3_location, :engine_arn, :runtime_version, :vpc_config, :visual_reference, :provisioned_resource_cleanup, :browser_configs, :engine_configs, :visual_references, :tags, :artifact_config, :dry_run_config) SENSITIVE = [] include Aws::Structure end |
#visual_reference ⇒ Types::VisualReferenceOutput
If this canary performs visual monitoring by comparing screenshots, this structure contains the ID of the canary run to use as the baseline for screenshots, and the coordinates of any parts of the screen to ignore during the visual monitoring comparison.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-synthetics/types.rb', line 324 class Canary < Struct.new( :id, :name, :code, :execution_role_arn, :schedule, :run_config, :success_retention_period_in_days, :failure_retention_period_in_days, :status, :timeline, :artifact_s3_location, :engine_arn, :runtime_version, :vpc_config, :visual_reference, :provisioned_resource_cleanup, :browser_configs, :engine_configs, :visual_references, :tags, :artifact_config, :dry_run_config) SENSITIVE = [] include Aws::Structure end |
#visual_references ⇒ Array<Types::VisualReferenceOutput>
A list of visual reference configurations for the canary, one for each browser type that the canary is configured to run on. Visual references are used for visual monitoring comparisons.
‘syn-nodejs-puppeteer-11.0` and above, and `syn-nodejs-playwright-3.0` and above, only supports `visualReferences`. `visualReference` field is not supported.
Versions older than ‘syn-nodejs-puppeteer-11.0` supports both `visualReference` and `visualReferences` for backward compatibility. It is recommended to use `visualReferences` for consistency and future compatibility.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-synthetics/types.rb', line 324 class Canary < Struct.new( :id, :name, :code, :execution_role_arn, :schedule, :run_config, :success_retention_period_in_days, :failure_retention_period_in_days, :status, :timeline, :artifact_s3_location, :engine_arn, :runtime_version, :vpc_config, :visual_reference, :provisioned_resource_cleanup, :browser_configs, :engine_configs, :visual_references, :tags, :artifact_config, :dry_run_config) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfigOutput
If this canary is to test an endpoint in a VPC, this structure contains information about the subnets and security groups of the VPC endpoint. For more information, see [ Running a Canary in a VPC].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch_Synthetics_Canaries_VPC.html
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-synthetics/types.rb', line 324 class Canary < Struct.new( :id, :name, :code, :execution_role_arn, :schedule, :run_config, :success_retention_period_in_days, :failure_retention_period_in_days, :status, :timeline, :artifact_s3_location, :engine_arn, :runtime_version, :vpc_config, :visual_reference, :provisioned_resource_cleanup, :browser_configs, :engine_configs, :visual_references, :tags, :artifact_config, :dry_run_config) SENSITIVE = [] include Aws::Structure end |