Class: Aws::Synthetics::Types::CanaryCodeOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Synthetics::Types::CanaryCodeOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-synthetics/types.rb
Overview
This structure contains information about the canary’s Lambda handler and where its code is stored by CloudWatch Synthetics.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#blueprint_types ⇒ Array<String>
BlueprintTypesis a list of templates that enable simplified canary creation. -
#dependencies ⇒ Array<Types::Dependency>
A list of dependencies that are used for running this canary.
-
#handler ⇒ String
The entry point to use for the source code when running the canary.
-
#source_location_arn ⇒ String
The ARN of the Lambda layer where Synthetics stores the canary script code.
Instance Attribute Details
#blueprint_types ⇒ Array<String>
BlueprintTypes is a list of templates that enable simplified canary creation. You can create canaries for common monitoring scenarios by providing only a JSON configuration file instead of writing custom scripts. The only supported value is multi-checks.
Multi-checks monitors HTTP/DNS/SSL/TCP endpoints with built-in authentication schemes (Basic, API Key, OAuth, SigV4) and assertion capabilities. When you specify BlueprintTypes, the Handler field cannot be specified since the blueprint provides a pre-defined entry point.
BlueprintTypes is supported only on canaries for syn-nodejs-3.0 runtime or later.
493 494 495 496 497 498 499 500 |
# File 'lib/aws-sdk-synthetics/types.rb', line 493 class CanaryCodeOutput < Struct.new( :source_location_arn, :handler, :blueprint_types, :dependencies) SENSITIVE = [] include Aws::Structure end |
#dependencies ⇒ Array<Types::Dependency>
A list of dependencies that are used for running this canary. The dependencies are specified as a key-value pair, where the key is the type of dependency and the value is the dependency reference.
493 494 495 496 497 498 499 500 |
# File 'lib/aws-sdk-synthetics/types.rb', line 493 class CanaryCodeOutput < Struct.new( :source_location_arn, :handler, :blueprint_types, :dependencies) SENSITIVE = [] include Aws::Structure end |
#handler ⇒ String
The entry point to use for the source code when running the canary.
This field is required when you don’t specify BlueprintTypes and is not allowed when you specify BlueprintTypes.
493 494 495 496 497 498 499 500 |
# File 'lib/aws-sdk-synthetics/types.rb', line 493 class CanaryCodeOutput < Struct.new( :source_location_arn, :handler, :blueprint_types, :dependencies) SENSITIVE = [] include Aws::Structure end |
#source_location_arn ⇒ String
The ARN of the Lambda layer where Synthetics stores the canary script code.
493 494 495 496 497 498 499 500 |
# File 'lib/aws-sdk-synthetics/types.rb', line 493 class CanaryCodeOutput < Struct.new( :source_location_arn, :handler, :blueprint_types, :dependencies) SENSITIVE = [] include Aws::Structure end |