Class: Aws::Synthetics::Types::CanaryRun
- Inherits:
-
Struct
- Object
- Struct
- Aws::Synthetics::Types::CanaryRun
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-synthetics/types.rb
Overview
This structure contains the details about one run of one canary.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#artifact_s3_location ⇒ String
The location where the canary stored artifacts from the run.
-
#browser_type ⇒ String
The browser type associated with this canary run.
-
#dry_run_config ⇒ Types::CanaryDryRunConfigOutput
Returns the dry run configurations for a canary.
-
#id ⇒ String
A unique ID that identifies this canary run.
-
#location ⇒ String
The Amazon Web Services Region where this canary run was executed.
-
#name ⇒ String
The name of the canary.
-
#retry_attempt ⇒ Integer
The count in number of the retry attempt.
-
#scheduled_run_id ⇒ String
The ID of the scheduled canary run.
-
#status ⇒ Types::CanaryRunStatus
The status of this run.
-
#timeline ⇒ Types::CanaryRunTimeline
A structure that contains the start and end times of this run.
Instance Attribute Details
#artifact_s3_location ⇒ String
The location where the canary stored artifacts from the run. Artifacts include the log file, screenshots, and HAR files.
612 613 614 615 616 617 618 619 620 621 622 623 624 625 |
# File 'lib/aws-sdk-synthetics/types.rb', line 612 class CanaryRun < Struct.new( :id, :scheduled_run_id, :retry_attempt, :name, :status, :timeline, :artifact_s3_location, :dry_run_config, :browser_type, :location) SENSITIVE = [] include Aws::Structure end |
#browser_type ⇒ String
The browser type associated with this canary run.
612 613 614 615 616 617 618 619 620 621 622 623 624 625 |
# File 'lib/aws-sdk-synthetics/types.rb', line 612 class CanaryRun < Struct.new( :id, :scheduled_run_id, :retry_attempt, :name, :status, :timeline, :artifact_s3_location, :dry_run_config, :browser_type, :location) SENSITIVE = [] include Aws::Structure end |
#dry_run_config ⇒ Types::CanaryDryRunConfigOutput
Returns the dry run configurations for a canary.
612 613 614 615 616 617 618 619 620 621 622 623 624 625 |
# File 'lib/aws-sdk-synthetics/types.rb', line 612 class CanaryRun < Struct.new( :id, :scheduled_run_id, :retry_attempt, :name, :status, :timeline, :artifact_s3_location, :dry_run_config, :browser_type, :location) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
A unique ID that identifies this canary run.
612 613 614 615 616 617 618 619 620 621 622 623 624 625 |
# File 'lib/aws-sdk-synthetics/types.rb', line 612 class CanaryRun < Struct.new( :id, :scheduled_run_id, :retry_attempt, :name, :status, :timeline, :artifact_s3_location, :dry_run_config, :browser_type, :location) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The Amazon Web Services Region where this canary run was executed.
612 613 614 615 616 617 618 619 620 621 622 623 624 625 |
# File 'lib/aws-sdk-synthetics/types.rb', line 612 class CanaryRun < Struct.new( :id, :scheduled_run_id, :retry_attempt, :name, :status, :timeline, :artifact_s3_location, :dry_run_config, :browser_type, :location) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the canary.
612 613 614 615 616 617 618 619 620 621 622 623 624 625 |
# File 'lib/aws-sdk-synthetics/types.rb', line 612 class CanaryRun < Struct.new( :id, :scheduled_run_id, :retry_attempt, :name, :status, :timeline, :artifact_s3_location, :dry_run_config, :browser_type, :location) SENSITIVE = [] include Aws::Structure end |
#retry_attempt ⇒ Integer
The count in number of the retry attempt.
612 613 614 615 616 617 618 619 620 621 622 623 624 625 |
# File 'lib/aws-sdk-synthetics/types.rb', line 612 class CanaryRun < Struct.new( :id, :scheduled_run_id, :retry_attempt, :name, :status, :timeline, :artifact_s3_location, :dry_run_config, :browser_type, :location) SENSITIVE = [] include Aws::Structure end |
#scheduled_run_id ⇒ String
The ID of the scheduled canary run.
612 613 614 615 616 617 618 619 620 621 622 623 624 625 |
# File 'lib/aws-sdk-synthetics/types.rb', line 612 class CanaryRun < Struct.new( :id, :scheduled_run_id, :retry_attempt, :name, :status, :timeline, :artifact_s3_location, :dry_run_config, :browser_type, :location) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::CanaryRunStatus
The status of this run.
612 613 614 615 616 617 618 619 620 621 622 623 624 625 |
# File 'lib/aws-sdk-synthetics/types.rb', line 612 class CanaryRun < Struct.new( :id, :scheduled_run_id, :retry_attempt, :name, :status, :timeline, :artifact_s3_location, :dry_run_config, :browser_type, :location) SENSITIVE = [] include Aws::Structure end |
#timeline ⇒ Types::CanaryRunTimeline
A structure that contains the start and end times of this run.
612 613 614 615 616 617 618 619 620 621 622 623 624 625 |
# File 'lib/aws-sdk-synthetics/types.rb', line 612 class CanaryRun < Struct.new( :id, :scheduled_run_id, :retry_attempt, :name, :status, :timeline, :artifact_s3_location, :dry_run_config, :browser_type, :location) SENSITIVE = [] include Aws::Structure end |