Class: Aws::Synthetics::Types::CreateCanaryRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-synthetics/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#add_replica_locationsArray<Types::AddReplicaLocationInput>

A list of locations (Amazon Web Services Regions) to add as replicas for the canary. Each location specifies a Region and optional VPC configuration for the replica. You can add up to 50 replica locations.

Returns:



1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
# File 'lib/aws-sdk-synthetics/types.rb', line 1182

class CreateCanaryRequest < Struct.new(
  :name,
  :code,
  :artifact_s3_location,
  :execution_role_arn,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :runtime_version,
  :vpc_config,
  :resources_to_replicate_tags,
  :provisioned_resource_cleanup,
  :browser_configs,
  :add_replica_locations,
  :tags,
  :artifact_config,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#artifact_configTypes::ArtifactConfigInput

A structure that contains the configuration for canary artifacts, including the encryption-at-rest settings for artifacts that the canary uploads to Amazon S3.



1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
# File 'lib/aws-sdk-synthetics/types.rb', line 1182

class CreateCanaryRequest < Struct.new(
  :name,
  :code,
  :artifact_s3_location,
  :execution_role_arn,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :runtime_version,
  :vpc_config,
  :resources_to_replicate_tags,
  :provisioned_resource_cleanup,
  :browser_configs,
  :add_replica_locations,
  :tags,
  :artifact_config,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#artifact_s3_locationString

The location in Amazon S3 where Synthetics stores artifacts from the test runs of this canary. Artifacts include the log file, screenshots, and HAR files. The name of the Amazon S3 bucket can't include a period (.).

Returns:

  • (String)


1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
# File 'lib/aws-sdk-synthetics/types.rb', line 1182

class CreateCanaryRequest < Struct.new(
  :name,
  :code,
  :artifact_s3_location,
  :execution_role_arn,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :runtime_version,
  :vpc_config,
  :resources_to_replicate_tags,
  :provisioned_resource_cleanup,
  :browser_configs,
  :add_replica_locations,
  :tags,
  :artifact_config,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#browser_configsArray<Types::BrowserConfig>

CloudWatch Synthetics now supports multibrowser canaries for syn-nodejs-puppeteer-11.0 and syn-nodejs-playwright-3.0 runtimes. This feature allows you to run your canaries on both Firefox and Chrome browsers. To create a multibrowser canary, you need to specify the BrowserConfigs with a list of browsers you want to use.

If not specified, browserConfigs defaults to Chrome.

Returns:



1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
# File 'lib/aws-sdk-synthetics/types.rb', line 1182

class CreateCanaryRequest < Struct.new(
  :name,
  :code,
  :artifact_s3_location,
  :execution_role_arn,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :runtime_version,
  :vpc_config,
  :resources_to_replicate_tags,
  :provisioned_resource_cleanup,
  :browser_configs,
  :add_replica_locations,
  :tags,
  :artifact_config,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#codeTypes::CanaryCodeInput

A structure that includes the entry point from which the canary should start running your script. If the script is stored in an Amazon S3 bucket, the bucket name, key, and version are also included.



1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
# File 'lib/aws-sdk-synthetics/types.rb', line 1182

class CreateCanaryRequest < Struct.new(
  :name,
  :code,
  :artifact_s3_location,
  :execution_role_arn,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :runtime_version,
  :vpc_config,
  :resources_to_replicate_tags,
  :provisioned_resource_cleanup,
  :browser_configs,
  :add_replica_locations,
  :tags,
  :artifact_config,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

The ARN of the IAM role to be used to run the canary. This role must already exist, and must include lambda.amazonaws.com as a principal in the trust policy. The role must also have the following permissions:

  • s3:PutObject

  • s3:GetBucketLocation

  • s3:ListAllMyBuckets

  • cloudwatch:PutMetricData

  • logs:CreateLogGroup

  • logs:CreateLogStream

  • logs:PutLogEvents

Returns:

  • (String)


1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
# File 'lib/aws-sdk-synthetics/types.rb', line 1182

class CreateCanaryRequest < Struct.new(
  :name,
  :code,
  :artifact_s3_location,
  :execution_role_arn,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :runtime_version,
  :vpc_config,
  :resources_to_replicate_tags,
  :provisioned_resource_cleanup,
  :browser_configs,
  :add_replica_locations,
  :tags,
  :artifact_config,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#failure_retention_period_in_daysInteger

The number of days to retain data about failed runs of this canary. If you omit this field, the default of 31 days is used. The valid range is 1 to 455 days.

This setting affects the range of information returned by GetCanaryRuns, as well as the range of information displayed in the Synthetics console.

Returns:

  • (Integer)


1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
# File 'lib/aws-sdk-synthetics/types.rb', line 1182

class CreateCanaryRequest < Struct.new(
  :name,
  :code,
  :artifact_s3_location,
  :execution_role_arn,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :runtime_version,
  :vpc_config,
  :resources_to_replicate_tags,
  :provisioned_resource_cleanup,
  :browser_configs,
  :add_replica_locations,
  :tags,
  :artifact_config,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arnString

The Amazon Resource Name (ARN) of the customer-managed AWS Key Management Service (AWS KMS) key used to encrypt the canary's AWS Lambda function environment variables at rest. If you don't specify a value, the service uses an AWS-managed key.

Returns:

  • (String)


1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
# File 'lib/aws-sdk-synthetics/types.rb', line 1182

class CreateCanaryRequest < Struct.new(
  :name,
  :code,
  :artifact_s3_location,
  :execution_role_arn,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :runtime_version,
  :vpc_config,
  :resources_to_replicate_tags,
  :provisioned_resource_cleanup,
  :browser_configs,
  :add_replica_locations,
  :tags,
  :artifact_config,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name for this canary. Be sure to give it a descriptive name that distinguishes it from other canaries in your account.

Do not include secrets or proprietary information in your canary names. The canary name makes up part of the canary ARN, and the ARN is included in outbound calls over the internet. For more information, see Security Considerations for Synthetics Canaries.

Returns:

  • (String)


1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
# File 'lib/aws-sdk-synthetics/types.rb', line 1182

class CreateCanaryRequest < Struct.new(
  :name,
  :code,
  :artifact_s3_location,
  :execution_role_arn,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :runtime_version,
  :vpc_config,
  :resources_to_replicate_tags,
  :provisioned_resource_cleanup,
  :browser_configs,
  :add_replica_locations,
  :tags,
  :artifact_config,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#provisioned_resource_cleanupString

Specifies whether to also delete the Lambda functions and layers used by this canary when the canary is deleted. If you omit this parameter, the default of AUTOMATIC is used, which means that the Lambda functions and layers will be deleted when the canary is deleted.

If the value of this parameter is OFF, then the value of the DeleteLambda parameter of the DeleteCanary operation determines whether the Lambda functions and layers will be deleted.

Returns:

  • (String)


1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
# File 'lib/aws-sdk-synthetics/types.rb', line 1182

class CreateCanaryRequest < Struct.new(
  :name,
  :code,
  :artifact_s3_location,
  :execution_role_arn,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :runtime_version,
  :vpc_config,
  :resources_to_replicate_tags,
  :provisioned_resource_cleanup,
  :browser_configs,
  :add_replica_locations,
  :tags,
  :artifact_config,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#resources_to_replicate_tagsArray<String>

To have the tags that you apply to this canary also be applied to the Lambda function that the canary uses, specify this parameter with the value lambda-function.

If you specify this parameter and don't specify any tags in the Tags parameter, the canary creation fails.

Returns:

  • (Array<String>)


1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
# File 'lib/aws-sdk-synthetics/types.rb', line 1182

class CreateCanaryRequest < Struct.new(
  :name,
  :code,
  :artifact_s3_location,
  :execution_role_arn,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :runtime_version,
  :vpc_config,
  :resources_to_replicate_tags,
  :provisioned_resource_cleanup,
  :browser_configs,
  :add_replica_locations,
  :tags,
  :artifact_config,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#run_configTypes::CanaryRunConfigInput

A structure that contains the configuration for individual canary runs, such as timeout value and environment variables.

Environment variable keys and values are encrypted at rest using Amazon Web Services owned KMS keys. However, the environment variables are not encrypted on the client side. Do not store sensitive information in them.



1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
# File 'lib/aws-sdk-synthetics/types.rb', line 1182

class CreateCanaryRequest < Struct.new(
  :name,
  :code,
  :artifact_s3_location,
  :execution_role_arn,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :runtime_version,
  :vpc_config,
  :resources_to_replicate_tags,
  :provisioned_resource_cleanup,
  :browser_configs,
  :add_replica_locations,
  :tags,
  :artifact_config,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#runtime_versionString

Specifies the runtime version to use for the canary. For a list of valid runtime versions and more information about runtime versions, see Canary Runtime Versions.

Returns:

  • (String)


1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
# File 'lib/aws-sdk-synthetics/types.rb', line 1182

class CreateCanaryRequest < Struct.new(
  :name,
  :code,
  :artifact_s3_location,
  :execution_role_arn,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :runtime_version,
  :vpc_config,
  :resources_to_replicate_tags,
  :provisioned_resource_cleanup,
  :browser_configs,
  :add_replica_locations,
  :tags,
  :artifact_config,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#scheduleTypes::CanaryScheduleInput

A structure that contains information about how often the canary is to run and when these test runs are to stop.



1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
# File 'lib/aws-sdk-synthetics/types.rb', line 1182

class CreateCanaryRequest < Struct.new(
  :name,
  :code,
  :artifact_s3_location,
  :execution_role_arn,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :runtime_version,
  :vpc_config,
  :resources_to_replicate_tags,
  :provisioned_resource_cleanup,
  :browser_configs,
  :add_replica_locations,
  :tags,
  :artifact_config,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#success_retention_period_in_daysInteger

The number of days to retain data about successful runs of this canary. If you omit this field, the default of 31 days is used. The valid range is 1 to 455 days.

This setting affects the range of information returned by GetCanaryRuns, as well as the range of information displayed in the Synthetics console.

Returns:

  • (Integer)


1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
# File 'lib/aws-sdk-synthetics/types.rb', line 1182

class CreateCanaryRequest < Struct.new(
  :name,
  :code,
  :artifact_s3_location,
  :execution_role_arn,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :runtime_version,
  :vpc_config,
  :resources_to_replicate_tags,
  :provisioned_resource_cleanup,
  :browser_configs,
  :add_replica_locations,
  :tags,
  :artifact_config,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A list of key-value pairs to associate with the canary. You can associate as many as 50 tags with a canary.

Tags can help you organize and categorize your resources. You can also use them to scope user permissions, by granting a user permission to access or change only the resources that have certain tag values.

To have the tags that you apply to this canary also be applied to the Lambda function that the canary uses, specify this parameter with the value lambda-function.

Returns:

  • (Hash<String,String>)


1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
# File 'lib/aws-sdk-synthetics/types.rb', line 1182

class CreateCanaryRequest < Struct.new(
  :name,
  :code,
  :artifact_s3_location,
  :execution_role_arn,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :runtime_version,
  :vpc_config,
  :resources_to_replicate_tags,
  :provisioned_resource_cleanup,
  :browser_configs,
  :add_replica_locations,
  :tags,
  :artifact_config,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::VpcConfigInput

If this canary is to test an endpoint in a VPC, this structure contains information about the subnet and security groups of the VPC endpoint. For more information, see Running a Canary in a VPC.



1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
# File 'lib/aws-sdk-synthetics/types.rb', line 1182

class CreateCanaryRequest < Struct.new(
  :name,
  :code,
  :artifact_s3_location,
  :execution_role_arn,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :runtime_version,
  :vpc_config,
  :resources_to_replicate_tags,
  :provisioned_resource_cleanup,
  :browser_configs,
  :add_replica_locations,
  :tags,
  :artifact_config,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end