Class: Aws::Synthetics::Types::DeleteCanaryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Synthetics::Types::DeleteCanaryRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-synthetics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delete_lambda ⇒ Boolean
Specifies whether to also delete the Lambda functions and layers used by this canary.
-
#name ⇒ String
The name of the canary that you want to delete.
Instance Attribute Details
#delete_lambda ⇒ Boolean
Specifies whether to also delete the Lambda functions and layers
used by this canary. The default is false.
Your setting for this parameter is used only if the canary doesn't
have AUTOMATIC for its ProvisionedResourceCleanup field. If that
field is set to AUTOMATIC, then the Lambda functions and layers
will be deleted when this canary is deleted.
Type: Boolean
1278 1279 1280 1281 1282 1283 |
# File 'lib/aws-sdk-synthetics/types.rb', line 1278 class DeleteCanaryRequest < Struct.new( :name, :delete_lambda) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the canary that you want to delete. To find the names of your canaries, use DescribeCanaries.
1278 1279 1280 1281 1282 1283 |
# File 'lib/aws-sdk-synthetics/types.rb', line 1278 class DeleteCanaryRequest < Struct.new( :name, :delete_lambda) SENSITIVE = [] include Aws::Structure end |