Class: Aws::Synthetics::Types::DescribeCanariesLastRunResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Synthetics::Types::DescribeCanariesLastRunResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-synthetics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#canaries_last_run ⇒ Array<Types::CanaryLastRun>
An array that contains the information from the most recent run of each canary.
-
#next_token ⇒ String
A token that indicates that there is more data available.
Instance Attribute Details
#canaries_last_run ⇒ Array<Types::CanaryLastRun>
An array that contains the information from the most recent run of each canary.
1390 1391 1392 1393 1394 1395 |
# File 'lib/aws-sdk-synthetics/types.rb', line 1390 class DescribeCanariesLastRunResponse < Struct.new( :canaries_last_run, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates that there is more data available. You can
use this token in a subsequent DescribeCanariesLastRun operation
to retrieve the next set of results.
1390 1391 1392 1393 1394 1395 |
# File 'lib/aws-sdk-synthetics/types.rb', line 1390 class DescribeCanariesLastRunResponse < Struct.new( :canaries_last_run, :next_token) SENSITIVE = [] include Aws::Structure end |