Class: Aws::Synthetics::Types::DescribeRuntimeVersionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Synthetics::Types::DescribeRuntimeVersionsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-synthetics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Specify this parameter to limit how many runs are returned each time you use the
DescribeRuntimeVersionsoperation. -
#next_token ⇒ String
A token that indicates that there is more data available.
Instance Attribute Details
#max_results ⇒ Integer
Specify this parameter to limit how many runs are returned each time
you use the DescribeRuntimeVersions operation. If you omit this
parameter, the default of 100 is used.
1472 1473 1474 1475 1476 1477 |
# File 'lib/aws-sdk-synthetics/types.rb', line 1472 class DescribeRuntimeVersionsRequest < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates that there is more data available. You can
use this token in a subsequent DescribeRuntimeVersions operation
to retrieve the next set of results.
1472 1473 1474 1475 1476 1477 |
# File 'lib/aws-sdk-synthetics/types.rb', line 1472 class DescribeRuntimeVersionsRequest < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |