Class: Aws::Synthetics::Types::DescribeRuntimeVersionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Synthetics::Types::DescribeRuntimeVersionsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-synthetics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A token that indicates that there is more data available.
-
#runtime_versions ⇒ Array<Types::RuntimeVersion>
An array of objects that display the details about each Synthetics canary runtime version.
Instance Attribute Details
#next_token ⇒ String
A token that indicates that there is more data available. You can
use this token in a subsequent DescribeRuntimeVersions operation
to retrieve the next set of results.
1492 1493 1494 1495 1496 1497 |
# File 'lib/aws-sdk-synthetics/types.rb', line 1492 class DescribeRuntimeVersionsResponse < Struct.new( :runtime_versions, :next_token) SENSITIVE = [] include Aws::Structure end |
#runtime_versions ⇒ Array<Types::RuntimeVersion>
An array of objects that display the details about each Synthetics canary runtime version.
1492 1493 1494 1495 1496 1497 |
# File 'lib/aws-sdk-synthetics/types.rb', line 1492 class DescribeRuntimeVersionsResponse < Struct.new( :runtime_versions, :next_token) SENSITIVE = [] include Aws::Structure end |