Class: Aws::Synthetics::Types::GetCanaryRunsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Synthetics::Types::GetCanaryRunsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-synthetics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run_id ⇒ String
The DryRunId associated with an existing canary’s dry run.
-
#max_results ⇒ Integer
Specify this parameter to limit how many runs are returned each time you use the
GetCanaryRunsoperation. -
#name ⇒ String
The name of the canary that you want to see runs for.
-
#next_token ⇒ String
A token that indicates that there is more data available.
-
#run_type ⇒ String
- When you provide
RunType=CANARY_RUNanddryRunId, you will get an exception.
- When you provide
Instance Attribute Details
#dry_run_id ⇒ String
The DryRunId associated with an existing canary’s dry run. You can use this DryRunId to retrieve information about the dry run.
1636 1637 1638 1639 1640 1641 1642 1643 1644 |
# File 'lib/aws-sdk-synthetics/types.rb', line 1636 class GetCanaryRunsRequest < Struct.new( :name, :next_token, :max_results, :dry_run_id, :run_type) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Specify this parameter to limit how many runs are returned each time
you use the GetCanaryRuns operation. If you omit this parameter,
the default of 100 is used.
1636 1637 1638 1639 1640 1641 1642 1643 1644 |
# File 'lib/aws-sdk-synthetics/types.rb', line 1636 class GetCanaryRunsRequest < Struct.new( :name, :next_token, :max_results, :dry_run_id, :run_type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the canary that you want to see runs for.
1636 1637 1638 1639 1640 1641 1642 1643 1644 |
# File 'lib/aws-sdk-synthetics/types.rb', line 1636 class GetCanaryRunsRequest < Struct.new( :name, :next_token, :max_results, :dry_run_id, :run_type) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates that there is more data available. You can
use this token in a subsequent GetCanaryRuns operation to retrieve
the next set of results.
1636 1637 1638 1639 1640 1641 1642 1643 1644 |
# File 'lib/aws-sdk-synthetics/types.rb', line 1636 class GetCanaryRunsRequest < Struct.new( :name, :next_token, :max_results, :dry_run_id, :run_type) SENSITIVE = [] include Aws::Structure end |
#run_type ⇒ String
-
When you provide
RunType=CANARY_RUNanddryRunId, you will get an exception -
When a value is not provided for
RunType, the default value isCANARY_RUN -
When
CANARY_RUNis provided, all canary runs excluding dry runs are returned -
When
DRY_RUNis provided, all dry runs excluding canary runs are returned
1636 1637 1638 1639 1640 1641 1642 1643 1644 |
# File 'lib/aws-sdk-synthetics/types.rb', line 1636 class GetCanaryRunsRequest < Struct.new( :name, :next_token, :max_results, :dry_run_id, :run_type) SENSITIVE = [] include Aws::Structure end |