Class: Aws::Synthetics::Types::ListGroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Synthetics::Types::ListGroupsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-synthetics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Specify this parameter to limit how many groups are returned each time you use the
ListGroupsoperation. -
#next_token ⇒ String
A token that indicates that there is more data available.
Instance Attribute Details
#max_results ⇒ Integer
Specify this parameter to limit how many groups are returned each
time you use the ListGroups operation. If you omit this parameter,
the default of 20 is used.
1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-synthetics/types.rb', line 1887 class ListGroupsRequest < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates that there is more data available. You can use this token in a subsequent operation to retrieve the next set of results.
1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-synthetics/types.rb', line 1887 class ListGroupsRequest < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |