Class: Aws::Synthetics::Types::ListGroupsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Synthetics::Types::ListGroupsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-synthetics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#groups ⇒ Array<Types::GroupSummary>
An array of structures that each contain information about one group.
-
#next_token ⇒ String
A token that indicates that there is more data available.
Instance Attribute Details
#groups ⇒ Array<Types::GroupSummary>
An array of structures that each contain information about one group.
1907 1908 1909 1910 1911 1912 |
# File 'lib/aws-sdk-synthetics/types.rb', line 1907 class ListGroupsResponse < Struct.new( :groups, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates that there is more data available. You can
use this token in a subsequent ListGroups operation to retrieve
the next set of results.
1907 1908 1909 1910 1911 1912 |
# File 'lib/aws-sdk-synthetics/types.rb', line 1907 class ListGroupsResponse < Struct.new( :groups, :next_token) SENSITIVE = [] include Aws::Structure end |