Class: Aws::Synthetics::Types::Replica

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-synthetics/types.rb

Overview

A structure that contains information about a canary replica in a specific location.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#canary_stateString

The current state of the canary in this replica location.

Returns:

  • (String)


1995
1996
1997
1998
1999
2000
2001
2002
2003
# File 'lib/aws-sdk-synthetics/types.rb', line 1995

class Replica < Struct.new(
  :location,
  :replication_status,
  :canary_state,
  :last_modified,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#last_modifiedTime

The date and time that the replica was last modified.

Returns:

  • (Time)


1995
1996
1997
1998
1999
2000
2001
2002
2003
# File 'lib/aws-sdk-synthetics/types.rb', line 1995

class Replica < Struct.new(
  :location,
  :replication_status,
  :canary_state,
  :last_modified,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

The Amazon Web Services Region where this replica is located.

Returns:

  • (String)


1995
1996
1997
1998
1999
2000
2001
2002
2003
# File 'lib/aws-sdk-synthetics/types.rb', line 1995

class Replica < Struct.new(
  :location,
  :replication_status,
  :canary_state,
  :last_modified,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#replication_statusTypes::ReplicationStatus

A structure that contains information about the replication status of this replica.



1995
1996
1997
1998
1999
2000
2001
2002
2003
# File 'lib/aws-sdk-synthetics/types.rb', line 1995

class Replica < Struct.new(
  :location,
  :replication_status,
  :canary_state,
  :last_modified,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::VpcConfigOutput

The VPC configuration for the canary replica in this location.



1995
1996
1997
1998
1999
2000
2001
2002
2003
# File 'lib/aws-sdk-synthetics/types.rb', line 1995

class Replica < Struct.new(
  :location,
  :replication_status,
  :canary_state,
  :last_modified,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end