Class: Aws::Synthetics::Types::ReplicationStatus

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-synthetics/types.rb

Overview

A structure that contains information about the replication status of a canary replica.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#stateString

The replication state of the replica. Valid values are InProgress, InSync, and Inconsistent.

Returns:

  • (String)


2049
2050
2051
2052
2053
2054
2055
# File 'lib/aws-sdk-synthetics/types.rb', line 2049

class ReplicationStatus < Struct.new(
  :state,
  :state_reason,
  :state_reason_code)
  SENSITIVE = []
  include Aws::Structure
end

#state_reasonString

A description that provides more detail about the current replication state.

Returns:

  • (String)


2049
2050
2051
2052
2053
2054
2055
# File 'lib/aws-sdk-synthetics/types.rb', line 2049

class ReplicationStatus < Struct.new(
  :state,
  :state_reason,
  :state_reason_code)
  SENSITIVE = []
  include Aws::Structure
end

#state_reason_codeString

A code that provides more detail about the current replication state.

Returns:

  • (String)


2049
2050
2051
2052
2053
2054
2055
# File 'lib/aws-sdk-synthetics/types.rb', line 2049

class ReplicationStatus < Struct.new(
  :state,
  :state_reason,
  :state_reason_code)
  SENSITIVE = []
  include Aws::Structure
end