Class: Aws::Synthetics::Types::StopCanaryRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-synthetics/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of the canary that you want to stop. To find the names of your canaries, use ListCanaries.

Returns:

  • (String)


2451
2452
2453
2454
2455
# File 'lib/aws-sdk-synthetics/types.rb', line 2451

class StopCanaryRequest < Struct.new(
  :name)
  SENSITIVE = []
  include Aws::Structure
end