Class: Aws::Synthetics::Types::UpdateCanaryRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-synthetics/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#add_replica_locationsArray<Types::AddReplicaLocationInput>

A list of locations (Amazon Web Services Regions) to add as replicas for the canary. Each location specifies a Region and optional VPC configuration for the replica. You can add up to 50 replica locations.

Returns:



2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
# File 'lib/aws-sdk-synthetics/types.rb', line 2742

class UpdateCanaryRequest < Struct.new(
  :name,
  :code,
  :execution_role_arn,
  :runtime_version,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :vpc_config,
  :visual_reference,
  :artifact_s3_location,
  :artifact_config,
  :provisioned_resource_cleanup,
  :dry_run_id,
  :visual_references,
  :browser_configs,
  :add_replica_locations,
  :remove_replica_locations,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#artifact_configTypes::ArtifactConfigInput

A structure that contains the configuration for canary artifacts, including the encryption-at-rest settings for artifacts that the canary uploads to Amazon S3.



2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
# File 'lib/aws-sdk-synthetics/types.rb', line 2742

class UpdateCanaryRequest < Struct.new(
  :name,
  :code,
  :execution_role_arn,
  :runtime_version,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :vpc_config,
  :visual_reference,
  :artifact_s3_location,
  :artifact_config,
  :provisioned_resource_cleanup,
  :dry_run_id,
  :visual_references,
  :browser_configs,
  :add_replica_locations,
  :remove_replica_locations,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#artifact_s3_locationString

The location in Amazon S3 where Synthetics stores artifacts from the test runs of this canary. Artifacts include the log file, screenshots, and HAR files. The name of the Amazon S3 bucket can't include a period (.).

Returns:

  • (String)


2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
# File 'lib/aws-sdk-synthetics/types.rb', line 2742

class UpdateCanaryRequest < Struct.new(
  :name,
  :code,
  :execution_role_arn,
  :runtime_version,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :vpc_config,
  :visual_reference,
  :artifact_s3_location,
  :artifact_config,
  :provisioned_resource_cleanup,
  :dry_run_id,
  :visual_references,
  :browser_configs,
  :add_replica_locations,
  :remove_replica_locations,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#browser_configsArray<Types::BrowserConfig>

A structure that specifies the browser type to use for a canary run. CloudWatch Synthetics supports running canaries on both CHROME and FIREFOX browsers.

If not specified, browserConfigs defaults to Chrome.

Returns:



2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
# File 'lib/aws-sdk-synthetics/types.rb', line 2742

class UpdateCanaryRequest < Struct.new(
  :name,
  :code,
  :execution_role_arn,
  :runtime_version,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :vpc_config,
  :visual_reference,
  :artifact_s3_location,
  :artifact_config,
  :provisioned_resource_cleanup,
  :dry_run_id,
  :visual_references,
  :browser_configs,
  :add_replica_locations,
  :remove_replica_locations,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#codeTypes::CanaryCodeInput

A structure that includes the entry point from which the canary should start running your script. If the script is stored in an Amazon S3 bucket, the bucket name, key, and version are also included.



2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
# File 'lib/aws-sdk-synthetics/types.rb', line 2742

class UpdateCanaryRequest < Struct.new(
  :name,
  :code,
  :execution_role_arn,
  :runtime_version,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :vpc_config,
  :visual_reference,
  :artifact_s3_location,
  :artifact_config,
  :provisioned_resource_cleanup,
  :dry_run_id,
  :visual_references,
  :browser_configs,
  :add_replica_locations,
  :remove_replica_locations,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#dry_run_idString

Update the existing canary using the updated configurations from the DryRun associated with the DryRunId.

When you use the dryRunId field when updating a canary, the only other field you can provide is the Schedule. Adding any other field will thrown an exception.

Returns:

  • (String)


2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
# File 'lib/aws-sdk-synthetics/types.rb', line 2742

class UpdateCanaryRequest < Struct.new(
  :name,
  :code,
  :execution_role_arn,
  :runtime_version,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :vpc_config,
  :visual_reference,
  :artifact_s3_location,
  :artifact_config,
  :provisioned_resource_cleanup,
  :dry_run_id,
  :visual_references,
  :browser_configs,
  :add_replica_locations,
  :remove_replica_locations,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

The ARN of the IAM role to be used to run the canary. This role must already exist, and must include lambda.amazonaws.com as a principal in the trust policy. The role must also have the following permissions:

  • s3:PutObject

  • s3:GetBucketLocation

  • s3:ListAllMyBuckets

  • cloudwatch:PutMetricData

  • logs:CreateLogGroup

  • logs:CreateLogStream

  • logs:CreateLogStream

Returns:

  • (String)


2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
# File 'lib/aws-sdk-synthetics/types.rb', line 2742

class UpdateCanaryRequest < Struct.new(
  :name,
  :code,
  :execution_role_arn,
  :runtime_version,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :vpc_config,
  :visual_reference,
  :artifact_s3_location,
  :artifact_config,
  :provisioned_resource_cleanup,
  :dry_run_id,
  :visual_references,
  :browser_configs,
  :add_replica_locations,
  :remove_replica_locations,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#failure_retention_period_in_daysInteger

The number of days to retain data about failed runs of this canary.

This setting affects the range of information returned by GetCanaryRuns, as well as the range of information displayed in the Synthetics console.

Returns:

  • (Integer)


2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
# File 'lib/aws-sdk-synthetics/types.rb', line 2742

class UpdateCanaryRequest < Struct.new(
  :name,
  :code,
  :execution_role_arn,
  :runtime_version,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :vpc_config,
  :visual_reference,
  :artifact_s3_location,
  :artifact_config,
  :provisioned_resource_cleanup,
  :dry_run_id,
  :visual_references,
  :browser_configs,
  :add_replica_locations,
  :remove_replica_locations,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arnString

The Amazon Resource Name (ARN) of the customer-managed AWS Key Management Service (AWS KMS) key used to encrypt the canary's AWS Lambda function environment variables at rest. If you don't specify a value, the service uses an AWS-managed key. If you omit this parameter, the service retains the existing value. To revert to the AWS-managed key, set this parameter to an empty string.

Returns:

  • (String)


2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
# File 'lib/aws-sdk-synthetics/types.rb', line 2742

class UpdateCanaryRequest < Struct.new(
  :name,
  :code,
  :execution_role_arn,
  :runtime_version,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :vpc_config,
  :visual_reference,
  :artifact_s3_location,
  :artifact_config,
  :provisioned_resource_cleanup,
  :dry_run_id,
  :visual_references,
  :browser_configs,
  :add_replica_locations,
  :remove_replica_locations,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the canary that you want to update. To find the names of your canaries, use DescribeCanaries.

You cannot change the name of a canary that has already been created.

Returns:

  • (String)


2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
# File 'lib/aws-sdk-synthetics/types.rb', line 2742

class UpdateCanaryRequest < Struct.new(
  :name,
  :code,
  :execution_role_arn,
  :runtime_version,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :vpc_config,
  :visual_reference,
  :artifact_s3_location,
  :artifact_config,
  :provisioned_resource_cleanup,
  :dry_run_id,
  :visual_references,
  :browser_configs,
  :add_replica_locations,
  :remove_replica_locations,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#provisioned_resource_cleanupString

Specifies whether to also delete the Lambda functions and layers used by this canary when the canary is deleted.

If the value of this parameter is OFF, then the value of the DeleteLambda parameter of the DeleteCanary operation determines whether the Lambda functions and layers will be deleted.

Returns:

  • (String)


2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
# File 'lib/aws-sdk-synthetics/types.rb', line 2742

class UpdateCanaryRequest < Struct.new(
  :name,
  :code,
  :execution_role_arn,
  :runtime_version,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :vpc_config,
  :visual_reference,
  :artifact_s3_location,
  :artifact_config,
  :provisioned_resource_cleanup,
  :dry_run_id,
  :visual_references,
  :browser_configs,
  :add_replica_locations,
  :remove_replica_locations,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#remove_replica_locationsArray<String>

A list of locations (Amazon Web Services Regions) to remove as replicas for the canary. You must specify at least one location to remove. All replicas can be removed in a single API call and you cannot remove the primary location.

Returns:

  • (Array<String>)


2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
# File 'lib/aws-sdk-synthetics/types.rb', line 2742

class UpdateCanaryRequest < Struct.new(
  :name,
  :code,
  :execution_role_arn,
  :runtime_version,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :vpc_config,
  :visual_reference,
  :artifact_s3_location,
  :artifact_config,
  :provisioned_resource_cleanup,
  :dry_run_id,
  :visual_references,
  :browser_configs,
  :add_replica_locations,
  :remove_replica_locations,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#run_configTypes::CanaryRunConfigInput

A structure that contains the timeout value that is used for each individual run of the canary.

Environment variable keys and values are encrypted at rest using Amazon Web Services owned KMS keys. However, the environment variables are not encrypted on the client side. Do not store sensitive information in them.



2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
# File 'lib/aws-sdk-synthetics/types.rb', line 2742

class UpdateCanaryRequest < Struct.new(
  :name,
  :code,
  :execution_role_arn,
  :runtime_version,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :vpc_config,
  :visual_reference,
  :artifact_s3_location,
  :artifact_config,
  :provisioned_resource_cleanup,
  :dry_run_id,
  :visual_references,
  :browser_configs,
  :add_replica_locations,
  :remove_replica_locations,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#runtime_versionString

Specifies the runtime version to use for the canary. For a list of valid runtime versions and for more information about runtime versions, see Canary Runtime Versions.

Returns:

  • (String)


2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
# File 'lib/aws-sdk-synthetics/types.rb', line 2742

class UpdateCanaryRequest < Struct.new(
  :name,
  :code,
  :execution_role_arn,
  :runtime_version,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :vpc_config,
  :visual_reference,
  :artifact_s3_location,
  :artifact_config,
  :provisioned_resource_cleanup,
  :dry_run_id,
  :visual_references,
  :browser_configs,
  :add_replica_locations,
  :remove_replica_locations,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#scheduleTypes::CanaryScheduleInput

A structure that contains information about how often the canary is to run, and when these runs are to stop.



2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
# File 'lib/aws-sdk-synthetics/types.rb', line 2742

class UpdateCanaryRequest < Struct.new(
  :name,
  :code,
  :execution_role_arn,
  :runtime_version,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :vpc_config,
  :visual_reference,
  :artifact_s3_location,
  :artifact_config,
  :provisioned_resource_cleanup,
  :dry_run_id,
  :visual_references,
  :browser_configs,
  :add_replica_locations,
  :remove_replica_locations,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#success_retention_period_in_daysInteger

The number of days to retain data about successful runs of this canary.

This setting affects the range of information returned by GetCanaryRuns, as well as the range of information displayed in the Synthetics console.

Returns:

  • (Integer)


2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
# File 'lib/aws-sdk-synthetics/types.rb', line 2742

class UpdateCanaryRequest < Struct.new(
  :name,
  :code,
  :execution_role_arn,
  :runtime_version,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :vpc_config,
  :visual_reference,
  :artifact_s3_location,
  :artifact_config,
  :provisioned_resource_cleanup,
  :dry_run_id,
  :visual_references,
  :browser_configs,
  :add_replica_locations,
  :remove_replica_locations,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#visual_referenceTypes::VisualReferenceInput

Defines the screenshots to use as the baseline for comparisons during visual monitoring comparisons during future runs of this canary. If you omit this parameter, no changes are made to any baseline screenshots that the canary might be using already.

Visual monitoring is supported only on canaries running the syn-puppeteer-node-3.2 runtime or later. For more information, see Visual monitoring and Visual monitoring blueprint



2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
# File 'lib/aws-sdk-synthetics/types.rb', line 2742

class UpdateCanaryRequest < Struct.new(
  :name,
  :code,
  :execution_role_arn,
  :runtime_version,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :vpc_config,
  :visual_reference,
  :artifact_s3_location,
  :artifact_config,
  :provisioned_resource_cleanup,
  :dry_run_id,
  :visual_references,
  :browser_configs,
  :add_replica_locations,
  :remove_replica_locations,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#visual_referencesArray<Types::VisualReferenceInput>

A list of visual reference configurations for the canary, one for each browser type that the canary is configured to run on. Visual references are used for visual monitoring comparisons.

syn-nodejs-puppeteer-11.0 and above, and syn-nodejs-playwright-3.0 and above, only supports visualReferences. visualReference field is not supported.

Versions older than syn-nodejs-puppeteer-11.0 supports both visualReference and visualReferences for backward compatibility. It is recommended to use visualReferences for consistency and future compatibility.

For multibrowser visual monitoring, you can update the baseline for all configured browsers in a single update call by specifying a list of VisualReference objects, one per browser. Each VisualReference object maps to a specific browser configuration, allowing you to manage visual baselines for multiple browsers simultaneously.

For single configuration canaries using Chrome browser (default browser), use visualReferences for syn-nodejs-puppeteer-11.0 and above, and syn-nodejs-playwright-3.0 and above canaries. The browserType in the visualReference object is not mandatory.

Returns:



2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
# File 'lib/aws-sdk-synthetics/types.rb', line 2742

class UpdateCanaryRequest < Struct.new(
  :name,
  :code,
  :execution_role_arn,
  :runtime_version,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :vpc_config,
  :visual_reference,
  :artifact_s3_location,
  :artifact_config,
  :provisioned_resource_cleanup,
  :dry_run_id,
  :visual_references,
  :browser_configs,
  :add_replica_locations,
  :remove_replica_locations,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::VpcConfigInput

If this canary is to test an endpoint in a VPC, this structure contains information about the subnet and security groups of the VPC endpoint. For more information, see Running a Canary in a VPC.



2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
# File 'lib/aws-sdk-synthetics/types.rb', line 2742

class UpdateCanaryRequest < Struct.new(
  :name,
  :code,
  :execution_role_arn,
  :runtime_version,
  :schedule,
  :run_config,
  :success_retention_period_in_days,
  :failure_retention_period_in_days,
  :vpc_config,
  :visual_reference,
  :artifact_s3_location,
  :artifact_config,
  :provisioned_resource_cleanup,
  :dry_run_id,
  :visual_references,
  :browser_configs,
  :add_replica_locations,
  :remove_replica_locations,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end