Method: Aws::Synthetics::Types::VisualReferenceInput#base_screenshots

Defined in:
lib/aws-sdk-synthetics/types.rb

#base_screenshotsArray<Types::BaseScreenshot>

An array of screenshots that will be used as the baseline for visual monitoring in future runs of this canary. If there is a screenshot that you don’t want to be used for visual monitoring, remove it from this array.

Returns:



2632
2633
2634
2635
2636
2637
2638
# File 'lib/aws-sdk-synthetics/types.rb', line 2632

class VisualReferenceInput < Struct.new(
  :base_screenshots,
  :base_canary_run_id,
  :browser_type)
  SENSITIVE = []
  include Aws::Structure
end