Class: Aws::Synthetics::Types::VisualReferenceOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-synthetics/types.rb

Overview

If this canary performs visual monitoring by comparing screenshots, this structure contains the ID of the canary run that is used as the baseline for screenshots, and the coordinates of any parts of those screenshots that are ignored during visual monitoring comparison.

Visual monitoring is supported only on canaries running the syn-puppeteer-node-3.2 runtime or later.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#base_canary_run_idString

The ID of the canary run that produced the baseline screenshots that are used for visual monitoring comparisons by this canary.

Returns:

  • (String)


2822
2823
2824
2825
2826
2827
2828
# File 'lib/aws-sdk-synthetics/types.rb', line 2822

class VisualReferenceOutput < Struct.new(
  :base_screenshots,
  :base_canary_run_id,
  :browser_type)
  SENSITIVE = []
  include Aws::Structure
end

#base_screenshotsArray<Types::BaseScreenshot>

An array of screenshots that are used as the baseline for comparisons during visual monitoring.

Returns:



2822
2823
2824
2825
2826
2827
2828
# File 'lib/aws-sdk-synthetics/types.rb', line 2822

class VisualReferenceOutput < Struct.new(
  :base_screenshots,
  :base_canary_run_id,
  :browser_type)
  SENSITIVE = []
  include Aws::Structure
end

#browser_typeString

The browser type associated with this visual reference.

Returns:

  • (String)


2822
2823
2824
2825
2826
2827
2828
# File 'lib/aws-sdk-synthetics/types.rb', line 2822

class VisualReferenceOutput < Struct.new(
  :base_screenshots,
  :base_canary_run_id,
  :browser_type)
  SENSITIVE = []
  include Aws::Structure
end