Class: Aws::Synthetics::Types::AddReplicaLocationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Synthetics::Types::AddReplicaLocationInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-synthetics/types.rb
Overview
A structure that specifies a replica location for a canary, including the Region and optional VPC configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#location ⇒ String
The Amazon Web Services Region where the canary replica should be created, for example ‘us-east-1`.
-
#vpc_config ⇒ Types::VpcConfigInput
The VPC configuration to use for the canary replica in this location.
Instance Attribute Details
#location ⇒ String
The Amazon Web Services Region where the canary replica should be created, for example ‘us-east-1`.
42 43 44 45 46 47 |
# File 'lib/aws-sdk-synthetics/types.rb', line 42 class AddReplicaLocationInput < Struct.new( :location, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfigInput
The VPC configuration to use for the canary replica in this location. If not specified, the replica runs without VPC connectivity.
42 43 44 45 46 47 |
# File 'lib/aws-sdk-synthetics/types.rb', line 42 class AddReplicaLocationInput < Struct.new( :location, :vpc_config) SENSITIVE = [] include Aws::Structure end |