Class: Aws::Synthetics::Types::ListGroupResourcesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Synthetics::Types::ListGroupResourcesRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-synthetics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#group_identifier ⇒ String
Specifies the group to return information for.
-
#max_results ⇒ Integer
Specify this parameter to limit how many canary ARNs are returned each time you use the
ListGroupResourcesoperation. -
#next_token ⇒ String
A token that indicates that there is more data available.
Instance Attribute Details
#group_identifier ⇒ String
Specifies the group to return information for. You can specify the
group name, the ARN, or the group ID as the GroupIdentifier.
1845 1846 1847 1848 1849 1850 1851 |
# File 'lib/aws-sdk-synthetics/types.rb', line 1845 class ListGroupResourcesRequest < Struct.new( :next_token, :max_results, :group_identifier) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Specify this parameter to limit how many canary ARNs are returned
each time you use the ListGroupResources operation. If you omit
this parameter, the default of 20 is used.
1845 1846 1847 1848 1849 1850 1851 |
# File 'lib/aws-sdk-synthetics/types.rb', line 1845 class ListGroupResourcesRequest < Struct.new( :next_token, :max_results, :group_identifier) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates that there is more data available. You can use this token in a subsequent operation to retrieve the next set of results.
1845 1846 1847 1848 1849 1850 1851 |
# File 'lib/aws-sdk-synthetics/types.rb', line 1845 class ListGroupResourcesRequest < Struct.new( :next_token, :max_results, :group_identifier) SENSITIVE = [] include Aws::Structure end |