Class: Aws::Synthetics::Types::MultiLocationConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-synthetics/types.rb

Overview

A structure that contains information about the multi-location configuration of a canary, including whether it is a primary or replica, the primary location, and the list of replicas.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#location_typeString

Indicates whether this canary is the ‘Primary` or a `Replica` in the multi-location configuration.

Returns:

  • (String)


1947
1948
1949
1950
1951
1952
1953
1954
# File 'lib/aws-sdk-synthetics/types.rb', line 1947

class MultiLocationConfig < Struct.new(
  :location_type,
  :primary_location,
  :replicas,
  :replication_state)
  SENSITIVE = []
  include Aws::Structure
end

#primary_locationString

The Amazon Web Services Region where the primary canary is located.

Returns:

  • (String)


1947
1948
1949
1950
1951
1952
1953
1954
# File 'lib/aws-sdk-synthetics/types.rb', line 1947

class MultiLocationConfig < Struct.new(
  :location_type,
  :primary_location,
  :replicas,
  :replication_state)
  SENSITIVE = []
  include Aws::Structure
end

#replicasArray<Types::Replica>

A list of replicas for this canary. This field is present only for the primary location canary.

Returns:



1947
1948
1949
1950
1951
1952
1953
1954
# File 'lib/aws-sdk-synthetics/types.rb', line 1947

class MultiLocationConfig < Struct.new(
  :location_type,
  :primary_location,
  :replicas,
  :replication_state)
  SENSITIVE = []
  include Aws::Structure
end

#replication_stateString

The overall replication state of the canary across all replica locations. This field is present only for the primary location canary. Valid values are ‘InProgress`, `InSync`, and `Inconsistent`.

Returns:

  • (String)


1947
1948
1949
1950
1951
1952
1953
1954
# File 'lib/aws-sdk-synthetics/types.rb', line 1947

class MultiLocationConfig < Struct.new(
  :location_type,
  :primary_location,
  :replicas,
  :replication_state)
  SENSITIVE = []
  include Aws::Structure
end