Class: Aws::Synthetics::Types::MultiLocationConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Synthetics::Types::MultiLocationConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-synthetics/types.rb
Overview
A structure that contains information about the multi-location configuration of a canary, including whether it is a primary or replica, the primary location, and the list of replicas.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#location_type ⇒ String
Indicates whether this canary is the ‘Primary` or a `Replica` in the multi-location configuration.
-
#primary_location ⇒ String
The Amazon Web Services Region where the primary canary is located.
-
#replicas ⇒ Array<Types::Replica>
A list of replicas for this canary.
-
#replication_state ⇒ String
The overall replication state of the canary across all replica locations.
Instance Attribute Details
#location_type ⇒ String
Indicates whether this canary is the ‘Primary` or a `Replica` in the multi-location configuration.
1947 1948 1949 1950 1951 1952 1953 1954 |
# File 'lib/aws-sdk-synthetics/types.rb', line 1947 class MultiLocationConfig < Struct.new( :location_type, :primary_location, :replicas, :replication_state) SENSITIVE = [] include Aws::Structure end |
#primary_location ⇒ String
The Amazon Web Services Region where the primary canary is located.
1947 1948 1949 1950 1951 1952 1953 1954 |
# File 'lib/aws-sdk-synthetics/types.rb', line 1947 class MultiLocationConfig < Struct.new( :location_type, :primary_location, :replicas, :replication_state) SENSITIVE = [] include Aws::Structure end |
#replicas ⇒ Array<Types::Replica>
A list of replicas for this canary. This field is present only for the primary location canary.
1947 1948 1949 1950 1951 1952 1953 1954 |
# File 'lib/aws-sdk-synthetics/types.rb', line 1947 class MultiLocationConfig < Struct.new( :location_type, :primary_location, :replicas, :replication_state) SENSITIVE = [] include Aws::Structure end |
#replication_state ⇒ String
The overall replication state of the canary across all replica locations. This field is present only for the primary location canary. Valid values are ‘InProgress`, `InSync`, and `Inconsistent`.
1947 1948 1949 1950 1951 1952 1953 1954 |
# File 'lib/aws-sdk-synthetics/types.rb', line 1947 class MultiLocationConfig < Struct.new( :location_type, :primary_location, :replicas, :replication_state) SENSITIVE = [] include Aws::Structure end |