Class: Aws::Synthetics::Types::ReplicationStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::Synthetics::Types::ReplicationStatus
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-synthetics/types.rb
Overview
A structure that contains information about the replication status of a canary replica.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#state ⇒ String
The replication state of the replica.
-
#state_reason ⇒ String
A description that provides more detail about the current replication state.
-
#state_reason_code ⇒ String
A code that provides more detail about the current replication state.
Instance Attribute Details
#state ⇒ String
The replication state of the replica. Valid values are ‘InProgress`, `InSync`, and `Inconsistent`.
2025 2026 2027 2028 2029 2030 2031 |
# File 'lib/aws-sdk-synthetics/types.rb', line 2025 class ReplicationStatus < Struct.new( :state, :state_reason, :state_reason_code) SENSITIVE = [] include Aws::Structure end |
#state_reason ⇒ String
A description that provides more detail about the current replication state.
2025 2026 2027 2028 2029 2030 2031 |
# File 'lib/aws-sdk-synthetics/types.rb', line 2025 class ReplicationStatus < Struct.new( :state, :state_reason, :state_reason_code) SENSITIVE = [] include Aws::Structure end |
#state_reason_code ⇒ String
A code that provides more detail about the current replication state.
2025 2026 2027 2028 2029 2030 2031 |
# File 'lib/aws-sdk-synthetics/types.rb', line 2025 class ReplicationStatus < Struct.new( :state, :state_reason, :state_reason_code) SENSITIVE = [] include Aws::Structure end |