Class: Aws::Synthetics::Types::StartCanaryDryRunRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Synthetics::Types::StartCanaryDryRunRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-synthetics/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#artifact_config ⇒ Types::ArtifactConfigInput
A structure that contains the configuration for canary artifacts, including the encryption-at-rest settings for artifacts that the canary uploads to Amazon S3.
-
#artifact_s3_location ⇒ String
The location in Amazon S3 where Synthetics stores artifacts from the test runs of this canary.
-
#browser_configs ⇒ Array<Types::BrowserConfig>
A structure that specifies the browser type to use for a canary run.
-
#code ⇒ Types::CanaryCodeInput
Use this structure to input your script code for the canary.
-
#execution_role_arn ⇒ String
The ARN of the IAM role to be used to run the canary.
-
#failure_retention_period_in_days ⇒ Integer
The number of days to retain data about failed runs of this canary.
-
#name ⇒ String
The name of the canary that you want to dry run.
-
#provisioned_resource_cleanup ⇒ String
Specifies whether to also delete the Lambda functions and layers used by this canary when the canary is deleted.
-
#run_config ⇒ Types::CanaryRunConfigInput
A structure that contains input information for a canary run.
-
#runtime_version ⇒ String
Specifies the runtime version to use for the canary.
-
#success_retention_period_in_days ⇒ Integer
The number of days to retain data about successful runs of this canary.
-
#visual_reference ⇒ Types::VisualReferenceInput
An object that specifies what screenshots to use as a baseline for visual monitoring by this canary.
-
#visual_references ⇒ Array<Types::VisualReferenceInput>
A list of visual reference configurations for the canary, one for each browser type that the canary is configured to run on.
-
#vpc_config ⇒ Types::VpcConfigInput
If this canary is to test an endpoint in a VPC, this structure contains information about the subnets and security groups of the VPC endpoint.
Instance Attribute Details
#artifact_config ⇒ Types::ArtifactConfigInput
A structure that contains the configuration for canary artifacts, including the encryption-at-rest settings for artifacts that the canary uploads to Amazon S3.
2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 |
# File 'lib/aws-sdk-synthetics/types.rb', line 2222 class StartCanaryDryRunRequest < Struct.new( :name, :code, :runtime_version, :run_config, :vpc_config, :execution_role_arn, :success_retention_period_in_days, :failure_retention_period_in_days, :visual_reference, :artifact_s3_location, :artifact_config, :provisioned_resource_cleanup, :browser_configs, :visual_references) SENSITIVE = [] include Aws::Structure end |
#artifact_s3_location ⇒ String
The location in Amazon S3 where Synthetics stores artifacts from the test runs of this canary. Artifacts include the log file, screenshots, and HAR files. The name of the Amazon S3 bucket can’t include a period (.).
2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 |
# File 'lib/aws-sdk-synthetics/types.rb', line 2222 class StartCanaryDryRunRequest < Struct.new( :name, :code, :runtime_version, :run_config, :vpc_config, :execution_role_arn, :success_retention_period_in_days, :failure_retention_period_in_days, :visual_reference, :artifact_s3_location, :artifact_config, :provisioned_resource_cleanup, :browser_configs, :visual_references) SENSITIVE = [] include Aws::Structure end |
#browser_configs ⇒ Array<Types::BrowserConfig>
A structure that specifies the browser type to use for a canary run. CloudWatch Synthetics supports running canaries on both ‘CHROME` and `FIREFOX` browsers.
<note markdown=“1”> If not specified, ‘browserConfigs` defaults to Chrome.
</note>
2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 |
# File 'lib/aws-sdk-synthetics/types.rb', line 2222 class StartCanaryDryRunRequest < Struct.new( :name, :code, :runtime_version, :run_config, :vpc_config, :execution_role_arn, :success_retention_period_in_days, :failure_retention_period_in_days, :visual_reference, :artifact_s3_location, :artifact_config, :provisioned_resource_cleanup, :browser_configs, :visual_references) SENSITIVE = [] include Aws::Structure end |
#code ⇒ Types::CanaryCodeInput
Use this structure to input your script code for the canary. This structure contains the Lambda handler with the location where the canary should start running the script. If the script is stored in an Amazon S3 bucket, the bucket name, key, and version are also included. If the script was passed into the canary directly, the script code is contained in the value of ‘Zipfile`.
If you are uploading your canary scripts with an Amazon S3 bucket, your zip file should include your script in a certain folder structure.
-
For Node.js canaries, the folder structure must be ‘nodejs/node_modules/myCanaryFilename.js ` For more information, see [Packaging your Node.js canary files]
-
For Python canaries, the folder structure must be ‘python/myCanaryFilename.py ` or `python/myFolder/myCanaryFilename.py ` For more information, see
- Packaging your Python canary files][2
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch_Synthetics_Canaries_WritingCanary_Nodejs.html#CloudWatch_Synthetics_Canaries_package [2]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch_Synthetics_Canaries_WritingCanary_Python.html#CloudWatch_Synthetics_Canaries_WritingCanary_Python_package
2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 |
# File 'lib/aws-sdk-synthetics/types.rb', line 2222 class StartCanaryDryRunRequest < Struct.new( :name, :code, :runtime_version, :run_config, :vpc_config, :execution_role_arn, :success_retention_period_in_days, :failure_retention_period_in_days, :visual_reference, :artifact_s3_location, :artifact_config, :provisioned_resource_cleanup, :browser_configs, :visual_references) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The ARN of the IAM role to be used to run the canary. This role must already exist, and must include ‘lambda.amazonaws.com` as a principal in the trust policy. The role must also have the following permissions:
2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 |
# File 'lib/aws-sdk-synthetics/types.rb', line 2222 class StartCanaryDryRunRequest < Struct.new( :name, :code, :runtime_version, :run_config, :vpc_config, :execution_role_arn, :success_retention_period_in_days, :failure_retention_period_in_days, :visual_reference, :artifact_s3_location, :artifact_config, :provisioned_resource_cleanup, :browser_configs, :visual_references) SENSITIVE = [] include Aws::Structure end |
#failure_retention_period_in_days ⇒ Integer
The number of days to retain data about failed runs of this canary. If you omit this field, the default of 31 days is used. The valid range is 1 to 455 days.
This setting affects the range of information returned by [GetCanaryRuns], as well as the range of information displayed in the Synthetics console.
[1]: docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_GetCanaryRuns.html
2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 |
# File 'lib/aws-sdk-synthetics/types.rb', line 2222 class StartCanaryDryRunRequest < Struct.new( :name, :code, :runtime_version, :run_config, :vpc_config, :execution_role_arn, :success_retention_period_in_days, :failure_retention_period_in_days, :visual_reference, :artifact_s3_location, :artifact_config, :provisioned_resource_cleanup, :browser_configs, :visual_references) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the canary that you want to dry run. To find canary names, use [DescribeCanaries].
[1]: docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_DescribeCanaries.html
2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 |
# File 'lib/aws-sdk-synthetics/types.rb', line 2222 class StartCanaryDryRunRequest < Struct.new( :name, :code, :runtime_version, :run_config, :vpc_config, :execution_role_arn, :success_retention_period_in_days, :failure_retention_period_in_days, :visual_reference, :artifact_s3_location, :artifact_config, :provisioned_resource_cleanup, :browser_configs, :visual_references) SENSITIVE = [] include Aws::Structure end |
#provisioned_resource_cleanup ⇒ String
Specifies whether to also delete the Lambda functions and layers used by this canary when the canary is deleted. If you omit this parameter, the default of ‘AUTOMATIC` is used, which means that the Lambda functions and layers will be deleted when the canary is deleted.
If the value of this parameter is ‘OFF`, then the value of the `DeleteLambda` parameter of the [DeleteCanary] operation determines whether the Lambda functions and layers will be deleted.
[1]: docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_DeleteCanary.html
2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 |
# File 'lib/aws-sdk-synthetics/types.rb', line 2222 class StartCanaryDryRunRequest < Struct.new( :name, :code, :runtime_version, :run_config, :vpc_config, :execution_role_arn, :success_retention_period_in_days, :failure_retention_period_in_days, :visual_reference, :artifact_s3_location, :artifact_config, :provisioned_resource_cleanup, :browser_configs, :visual_references) SENSITIVE = [] include Aws::Structure end |
#run_config ⇒ Types::CanaryRunConfigInput
A structure that contains input information for a canary run.
2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 |
# File 'lib/aws-sdk-synthetics/types.rb', line 2222 class StartCanaryDryRunRequest < Struct.new( :name, :code, :runtime_version, :run_config, :vpc_config, :execution_role_arn, :success_retention_period_in_days, :failure_retention_period_in_days, :visual_reference, :artifact_s3_location, :artifact_config, :provisioned_resource_cleanup, :browser_configs, :visual_references) SENSITIVE = [] include Aws::Structure end |
#runtime_version ⇒ String
Specifies the runtime version to use for the canary. For a list of valid runtime versions and for more information about runtime versions, see [ Canary Runtime Versions].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch_Synthetics_Canaries_Library.html
2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 |
# File 'lib/aws-sdk-synthetics/types.rb', line 2222 class StartCanaryDryRunRequest < Struct.new( :name, :code, :runtime_version, :run_config, :vpc_config, :execution_role_arn, :success_retention_period_in_days, :failure_retention_period_in_days, :visual_reference, :artifact_s3_location, :artifact_config, :provisioned_resource_cleanup, :browser_configs, :visual_references) SENSITIVE = [] include Aws::Structure end |
#success_retention_period_in_days ⇒ Integer
The number of days to retain data about successful runs of this canary. If you omit this field, the default of 31 days is used. The valid range is 1 to 455 days.
This setting affects the range of information returned by [GetCanaryRuns], as well as the range of information displayed in the Synthetics console.
[1]: docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_GetCanaryRuns.html
2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 |
# File 'lib/aws-sdk-synthetics/types.rb', line 2222 class StartCanaryDryRunRequest < Struct.new( :name, :code, :runtime_version, :run_config, :vpc_config, :execution_role_arn, :success_retention_period_in_days, :failure_retention_period_in_days, :visual_reference, :artifact_s3_location, :artifact_config, :provisioned_resource_cleanup, :browser_configs, :visual_references) SENSITIVE = [] include Aws::Structure end |
#visual_reference ⇒ Types::VisualReferenceInput
An object that specifies what screenshots to use as a baseline for visual monitoring by this canary. It can optionally also specify parts of the screenshots to ignore during the visual monitoring comparison.
Visual monitoring is supported only on canaries running the syn-puppeteer-node-3.2 runtime or later. For more information, see [ Visual monitoring] and [ Visual monitoring blueprint]
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch_Synthetics_Library_SyntheticsLogger_VisualTesting.html [2]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch_Synthetics_Canaries_Blueprints_VisualTesting.html
2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 |
# File 'lib/aws-sdk-synthetics/types.rb', line 2222 class StartCanaryDryRunRequest < Struct.new( :name, :code, :runtime_version, :run_config, :vpc_config, :execution_role_arn, :success_retention_period_in_days, :failure_retention_period_in_days, :visual_reference, :artifact_s3_location, :artifact_config, :provisioned_resource_cleanup, :browser_configs, :visual_references) SENSITIVE = [] include Aws::Structure end |
#visual_references ⇒ Array<Types::VisualReferenceInput>
A list of visual reference configurations for the canary, one for each browser type that the canary is configured to run on. Visual references are used for visual monitoring comparisons.
‘syn-nodejs-puppeteer-11.0` and above, and `syn-nodejs-playwright-3.0` and above, only supports `visualReferences`. `visualReference` field is not supported.
Versions older than ‘syn-nodejs-puppeteer-11.0` supports both `visualReference` and `visualReferences` for backward compatibility. It is recommended to use `visualReferences` for consistency and future compatibility.
2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 |
# File 'lib/aws-sdk-synthetics/types.rb', line 2222 class StartCanaryDryRunRequest < Struct.new( :name, :code, :runtime_version, :run_config, :vpc_config, :execution_role_arn, :success_retention_period_in_days, :failure_retention_period_in_days, :visual_reference, :artifact_s3_location, :artifact_config, :provisioned_resource_cleanup, :browser_configs, :visual_references) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfigInput
If this canary is to test an endpoint in a VPC, this structure contains information about the subnets and security groups of the VPC endpoint. For more information, see [ Running a Canary in a VPC].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch_Synthetics_Canaries_VPC.html
2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 |
# File 'lib/aws-sdk-synthetics/types.rb', line 2222 class StartCanaryDryRunRequest < Struct.new( :name, :code, :runtime_version, :run_config, :vpc_config, :execution_role_arn, :success_retention_period_in_days, :failure_retention_period_in_days, :visual_reference, :artifact_s3_location, :artifact_config, :provisioned_resource_cleanup, :browser_configs, :visual_references) SENSITIVE = [] include Aws::Structure end |